==> gammaray_2.5.1.orig.tar.xz: gammaray-2.5.1/plugins/widgetinspector/waextension/widgetattributeextension.h <==
/*
  widgetattributeextension.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_WIDGETATTRIBUTEEXTENSION_H
#define GAMMARAY_WIDGETATTRIBUTEEXTENSION_H

#include <core/propertycontrollerextension.h>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace GammaRay {
template<typename, typename> class AttributeModel;

class WidgetAttributeExtension : public PropertyControllerExtension
{
public:
    explicit WidgetAttributeExtension(PropertyController *controller);
    ~WidgetAttributeExtension();

    bool setQObject(QObject *object) Q_DECL_OVERRIDE;

private:
    AttributeModel<QWidget, Qt::WidgetAttribute> *m_attributeModel;
};
}

#endif // GAMMARAY_WIDGETATTRIBUTEEXTENSION_H

==> gammaray_2.7.0.orig.tar.xz: gammaray-2.7.0/plugins/widgetinspector/waextension/widgetattributeextension.h <==
/*
  widgetattributeextension.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2016-2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_WIDGETATTRIBUTEEXTENSION_H
#define GAMMARAY_WIDGETATTRIBUTEEXTENSION_H

#include <core/propertycontrollerextension.h>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace GammaRay {
template<typename, typename> class AttributeModel;

class WidgetAttributeExtension : public PropertyControllerExtension
{
public:
    explicit WidgetAttributeExtension(PropertyController *controller);
    ~WidgetAttributeExtension();

    bool setQObject(QObject *object) override;

private:
    AttributeModel<QWidget, Qt::WidgetAttribute> *m_attributeModel;
};
}

#endif // GAMMARAY_WIDGETATTRIBUTEEXTENSION_H
